@@ -17,8 +17,6 @@ def query_results(query: str, page=1):
         status("Fetching DuckDuckGo result page...")
         search_url = f"https://html.duckduckgo.com/html/?q={quote(query)}&s={(page-1)*20}"  # noqa: E501
         content = get_url_content(search_url)
-        with open("/tmp/preview.html", "w") as f:
-            f.write(content)
         page_links = set()
         for link in LINK_REGEXP.findall(content):
             if link.startswith("http"):
